@@ -53,7 +53,7 @@ typedef struct
 	
 	char    *startpath;			// startin path  cwd
 	char    *homepath;			// ~
-	char    *userdatapath;		// ~/.liqbase
+	char    *userdatapath;			// ~/.liqbase
 	char    *codepath;			// /usr/share/liqbase		// where code files live (should contain media and widgets subfolders)
 
 	char    *username;			// lcuk or whatever is in ~/.liqbase/liqbase.prefs
@@ -112,8 +112,8 @@ int 		liqapp_formatnow(char *buffer,int buffersize, const char *format);
 int liqapp_datestamp_to_date(char *datestamp,struct tm *timebuf);		// convert a liqbase datestamp "yyyymmdd_hhmmss" into a tm struct
 
 
-char * 		liqapp_format_strftime(char *buffer,int buffersize,char *strftime_fmt);
-
+char * 		liqapp_format_strftime(char *buffer,int buffersize,char *strftime_fmt);			// use format specifiers to display time
+char * 		liqapp_format_strftime_human(char *buffer,int buffersize,struct tm *ts);		// print a human readable (english only) string of time
 
 int 		liqapp_folderexists(const char *pathname);
 int   		liqapp_pathexists(const char *pathname);
