@@ -20,13 +20,12 @@
  * Header for basic sketch
  *
  */
-
-
-
-
 #ifndef LIQSKETCH_H
 #define LIQSKETCH_H
 
+#ifdef __cplusplus
+extern "C" {
+#endif
 
 #include "liqimage.h"
 
@@ -62,9 +61,9 @@ void    		liqpoint_free(liqpoint *self);
 
 
 liqpoint         *liqpoint_clone(liqpoint *s);
-inline void   liqpoint_copy(liqpoint *self,liqpoint *s) ;
-inline void   liqpoint_getdiff(liqpoint *self,liqpoint *s,liqpoint *e) ;
-inline int    liqpoint_issame(liqpoint *self,liqpoint *s);
+void   liqpoint_copy(liqpoint *self,liqpoint *s) ;
+void   liqpoint_getdiff(liqpoint *self,liqpoint *s,liqpoint *e) ;
+int    liqpoint_issame(liqpoint *self,liqpoint *s);
 
 //##################################################################
 
@@ -79,7 +78,10 @@ typedef struct liqpointrange
 } liqpointrange;
 void          liqpointrange_start(liqpointrange *self,liqpoint *p);
 void          liqpointrange_extendrubberband(liqpointrange *self,liqpoint *p);
+void          liqpointrange_start_xyz(liqpointrange *self,int px,int py,int pz);
+void          liqpointrange_extendrubberband_xyz(liqpointrange *self,int px,int py,int pz);
 
+int           liqpointrange_isconnected(liqpointrange *self,liqpointrange *b);
 //##################################################################
 typedef struct liqstroke 
 {
@@ -168,6 +170,8 @@ typedef struct liqsketch
 	char *		  		backgroundfilename;
 	liqimage *	  		backgroundimage;
 	struct liqsketch *	backgroundsketch;
+	
+	float               angle;					// render rotation angle to use
 
 	
 	//struct liqcell *		extratokens;			// a set of tokens which did not match the normal defs, loaded and saved with the file			
@@ -198,10 +202,14 @@ int 		  liqsketch_filesave(liqsketch *self,char *filename);
 int 		  liqsketch_fileload(liqsketch *self,char *filename);
 int           liqsketch_fileload_memstream(liqsketch *self,char *filename,char *srcdata, int srcsize);
 
-void          liqsketch_boundwholearea();
+void          liqsketch_boundwholearea(liqsketch *self);
 
 void 		  liqsketch_coordchange_scr_to_page(liqsketch *self,int scrx,int scry,int scrw,int scrh, int scrdpix,int scrdpiy,int *rx,int *ry);
 void 		  liqsketch_islandcalcall(liqsketch *self);		// identify the islands within this page :)
 
+#ifdef __cplusplus
+}
+#endif
+
 
 #endif
