@@ -248,7 +248,9 @@ void liqcell_setpos(liqcell *self,int x,int y)
 	if(self->x==x && self->y==y)return;
 	self->x=x;
 	self->y=y;
+//liqapp_log("move start '%s'",self->name);
 	liqcell_handlerrun(self,"move",NULL);
+//liqapp_log("move fin   '%s'",self->name);
 }
 
 /**
@@ -786,7 +788,7 @@ void liqcell_setshown(liqcell *self,int arg)
 	}
 	else
 	{
-		self->kind &= !cellkind_shown;
+		self->kind &= ~cellkind_shown;
 	}
 }
 
@@ -889,7 +891,6 @@ liqcell *liqcell_getlinkchild_visual(liqcell *self)
 
 
 
-
 /**
  * Get the linked previous of the liqcell, the previous link in the linked list that is VISIBLE - that is, set to show now
  * @param self The liqcell to lookup
@@ -1290,6 +1291,47 @@ liqcell*  liqcell_child_insert(liqcell *self,liqcell *child)
 	return child;
 }
 
+
+
+liqcell*  liqcell_child_insertbefore(liqcell *self,liqcell *child, liqcell*placeholder)
+{
+	// insert the child into the tree
+	if(!child)return NULL;
+	if(!placeholder) return NULL;
+	if(!placeholder->linkprev) return liqcell_child_insert(self,child);
+	
+	//liqcell_hold(child);
+	child->linkparent=(self);
+	child->linkprev=placeholder->linkprev; // we are at the start
+	child->linknext=placeholder;
+
+	child->linkprev->linknext = child;
+	placeholder->linkprev = child;
+	//self->childcount++;
+	liqcell_setdirty(self,1);
+	return child;
+}
+
+liqcell*  liqcell_child_insertafter(liqcell *self,liqcell *child, liqcell*placeholder)
+{
+	// insert the child into the tree
+	if(!child)return NULL;
+	if(!placeholder) return NULL;
+	if(!placeholder->linknext) return liqcell_child_append(self,child);
+	
+	//liqcell_hold(child);
+	child->linkparent=(self);
+	child->linkprev=placeholder;
+	child->linknext=placeholder->linknext; // we are at the start
+
+
+	child->linknext->linkprev = child;
+	placeholder->linknext = child;
+	//self->childcount++;
+	liqcell_setdirty(self,1);
+	return child;
+}
+
 /**
  * Count the number of visible children
  * @param self The liqcell to count the children of
@@ -1335,6 +1377,18 @@ int liqcell_child_countselected(liqcell *self)
 	}
 	return answercount;
 }
+
+liqcell * liqcell_child_getfirstselected(liqcell *self)
+{
+	liqcell *c;
+	c=liqcell_getlinkchild_visual(self);
+	while(c)
+	{
+		if( liqcell_getselected(c) ) return c;
+		c=liqcell_getlinknext_visual(c);
+	}
+	return NULL;
+}
 /**
  * Create a chain in an already linked list of liqcells. If a list doesn't exist for the parent
  * (self) then start a new list. Set the child's parent to the parent of the list, and the 
@@ -1888,7 +1942,13 @@ liqcell*  liqcell_quickcreatevis(const char *name, const char *classname,int x,i
 	
 	
 	liqcell_setname(self,name);
-	if((w>0) || (h>0))	liqcell_setrect(self,x,y,w,h);     // 20090422_184637 lcuk : only set the dimensions when we have valid ones
+	if((w>0) || (h>0))	
+	{
+		liqcell_setrect(self,x,y,w,h);     // 20090422_184637 lcuk : only set the dimensions when we have valid ones
+		liqcell_setinnersize_from_outer(self);		// this ensures that widgets have an initial scale
+	}
+	self->startx = x; self->starty = y;
+
 
 	return self;
 }
@@ -2234,10 +2294,10 @@ static int lowest(int a,int b)
 {
 	if(abs(a)<abs(b))
 	{
-		liqapp_log("lowest %i :: %i = a %i",a,b,a);
+	//	liqapp_log("lowest %i :: %i = a %i",a,b,a);
 		return a;
 	}
-	liqapp_log("lowest %i :: %i = b %i",a,b,b);
+	//liqapp_log("lowest %i :: %i = b %i",a,b,b);
 	return b;
 }
 
@@ -2249,7 +2309,7 @@ static int dimension_ensurevisible( int rs,int re,    int ps,int pe, int ss,int
 	// to slide the rule along so s is visible :)
 	//ss += ps;	// start by adjusting 
 	//se += pe;
-	liqapp_log("dim ol: r(%i,%i)   p(%i,%i)    s(%i,%i)",   rs,re,     ps,pe,     ss,se);
+	//liqapp_log("dim ol: r(%i,%i)   p(%i,%i)    s(%i,%i)",   rs,re,     ps,pe,     ss,se);
 	if(re<=ss)
 	{
 		// S is way below, lets adjust
@@ -2278,7 +2338,7 @@ static int dimension_ensurevisible( int rs,int re,    int ps,int pe, int ss,int
  */
 int liqcell_ensurevisible(liqcell *self)
 {
-	liqapp_log("ensure: %s",self->name);
+	//liqapp_log("ensure: %s",self->name);
 	int xs=self->x;
 	int xe=self->x+self->w;
 	int ys=self->y;
@@ -2291,7 +2351,7 @@ int liqcell_ensurevisible(liqcell *self)
 		liqcell *r=liqcell_getlinkparent(p);
 		if(r)
 		{
-			liqapp_log("trying in : %s",p->name);
+			//liqapp_log("trying in : %s",p->name);
 			xs+=p->x;
 			xe+=p->x;
 			ys+=p->y;
@@ -2302,7 +2362,7 @@ int liqcell_ensurevisible(liqcell *self)
 			int ay = -dimension_ensurevisible(0,r->h,   p->y,p->y+p->h,   ys,ye);
 
 
-			liqapp_log("gave me : a(%i,%i)",  ax,ay);
+			//liqapp_log("gave me : a(%i,%i)",  ax,ay);
 
 			liqcell_adjustpos(p,ax,ay);
 			xs-=ax;
@@ -2323,7 +2383,7 @@ int liqcell_ensurevisible(liqcell *self)
  */
 int liqcell_ensurevisible_centred(liqcell *self)
 {
-	liqapp_log("ensure: %s",self->name);
+	//liqapp_log("ensure: %s",self->name);
 	int xs=self->x;
 	int xe=self->x+self->w;
 	int ys=self->y;
@@ -2336,7 +2396,7 @@ int liqcell_ensurevisible_centred(liqcell *self)
 		liqcell *r=liqcell_getlinkparent(p);
 		if(r)
 		{
-			liqapp_log("trying in : %s",p->name);
+			//liqapp_log("trying in : %s",p->name);
 			xs+=p->x;
 			xe+=p->x;
 			ys+=p->y;
@@ -2347,7 +2407,7 @@ int liqcell_ensurevisible_centred(liqcell *self)
 			int ay = -dimension_ensurevisible(r->h*0.5,r->h*0.5,   p->y,p->y+p->h,   ys,ye);
 
 
-			liqapp_log("gave me : a(%i,%i)",  ax,ay);
+			//liqapp_log("gave me : a(%i,%i)",  ax,ay);
 
 			liqcell_adjustpos(p,ax,ay);
 			xs-=ax;
