@@ -43,7 +43,7 @@ extern "C" {
 
 int liqcell_showdebugboxes=0;
 int liqcell_showfps=0;
-
+int liqcell_liqfloat_drunkenmode=0;
 
 
 liqimage *easypaint_isloading_image = NULL;
@@ -572,6 +572,10 @@ static int liqcell_kineticboiloff(liqcell *self)
 
 		//liqapp_log("kinetic pre motion... k=%2i,%2i  d=%i,%i    p=%i,%i s=%i,%i", self->kineticx , self->kineticy,   dx,dy,    px,py , self->x,self->y );
 
+		if(-px<0)px=0;
+		if(-py<0)py=0;
+		if(-px>self->w-par->w)px=-(self->w-par->w);
+		if(-py>self->h-par->h)py=-(self->h-par->h);
 
 		liqcell_setpos(self,px,py);
 
@@ -587,7 +591,7 @@ static int liqcell_kineticboiloff(liqcell *self)
 //
 }
 
-void liqcell_check_for_driedup(liqcell *self)
+void liqcell_check_for_driedup(liqcell *self,char *reason)
 {
 	if( !self->paintlastframenumber ) return;	// never painted
 	
@@ -595,7 +599,7 @@ void liqcell_check_for_driedup(liqcell *self)
 	
 	// its been painted a while ago, and its now offscreen
 	// tell the cell its going offscreen
-	liqapp_log("dried up '%s'",self->name);
+	liqapp_log("dried up '%s' (add handler for 'driedup' to free content) :: '%s'",self->name,reason);
 	self->paintlastframenumber=0;
 	liqcell_handlerrun(self,"driedup",NULL);
 	
@@ -608,19 +612,19 @@ void liqcell_easypaintkkk(liqcell *self,liqcliprect *crorig,    int x,int y,
 	if(w<1 || h<1)
 	{
 		//liqapp_log("size0 bail!");
-		liqcell_check_for_driedup(self);
+		liqcell_check_for_driedup(self,"size0 bail");
 		return;
 	}
 	if(self->w==0 || self->h==0)
 	{
 		//liqapp_log("box0 bail!");
-		liqcell_check_for_driedup(self);
+		liqcell_check_for_driedup(self,"box0 bail");
 		return;
 	}
 	if(!self->visible)
 	{
 		//liqapp_log("vis bail!");
-		liqcell_check_for_driedup(self);
+		liqcell_check_for_driedup(self,"vis bail");
 		return;
 	}
 	// shit this is at wrong location, theres many reasons to bailout which this does not handle
@@ -638,7 +642,7 @@ void liqcell_easypaintkkk(liqcell *self,liqcliprect *crorig,    int x,int y,
 	if(!liqcliprect_isvalid(crvis))
 	{
 		//liqapp_log("cr bail!");
-		liqcell_check_for_driedup(self);
+		liqcell_check_for_driedup(self,"cr bail");
 		liqcliprect_release(crvis);
 		return;
 	}
@@ -727,31 +731,12 @@ long tzused=0;
 __tz_one("start");
 
 
-
-
-//char cy,cu,cv;
-/*
-
-	if(w<1 || h<1)
-	{
-		//liqapp_log("size0 bail!");
-		liqcell_check_for_driedup(self);
-		return;
-	}
-	if(self->w==0 || self->h==0)
-	{
-		//liqapp_log("box0 bail!");
-		liqcell_check_for_driedup(self);
-		return;
-	}
-	if(!self->visible)
-	{
-		//liqapp_log("vis bail!");
-		liqcell_check_for_driedup(self);
-		return;
-	}
-*/	
 	//liqapp_log("easypaint 0");
+
+
+
+int triedlayout = 0;
+	layoutrestart:
 	
 __tz_one("sizeok");
 
@@ -767,12 +752,18 @@ __tz_one("clipgot");
 	if(!liqcliprect_isvalid(cr))
 	{
 		//liqapp_log("cr bail!");
-		liqcell_check_for_driedup(self);
+		//char buf[1024];
+		//snprintf(buf,sizeof(buf),"cr bail new(sxy(%d,%d) exy(%d,%d))   orig(sxy(%d,%d) exy(%d,%d)) frame(sxy(%d,%d) exy(%d,%d))",  cr->sx,cr->sy,   cr->ex,cr->ey,   crorig->sx,crorig->sy,   crorig->ex,crorig->ey,    x,y,x+w,y+h);
+		liqcell_check_for_driedup(self,"cr bail");
 		liqcliprect_release(cr);
 		return;
 	}
 __tz_one("clipok");
 
+
+
+
+
 	// onscreen, so save the frame number away
 	self->paintlastframenumber = canvas.framecount;
 
@@ -894,35 +885,64 @@ __tz_one("paintdone");
 			//liqapp_log("textcolor :: '%s'",t);
 			if(decodecolor(t, &bcy, &bcu, &bcv, &bca, &bcc ))
 			{
-                // play...
-                if( (!self->image) && (self->classname) && (bca==255) && (bcc==0) )
-                {
-                    if(!easypaint_backgrain_image)
-                    {
-						// try allowing with alpha..
-                         easypaint_backgrain_image=liqimage_newfromfile("/usr/share/liqbase/libliqbase/media/backgrain.png",0,0,0);
-                    }
-                    if(easypaint_backgrain_image)
-                    {
-                        //if(bca==255)
-                            liqcliprect_drawimagecolor(cr,easypaint_backgrain_image,x,y,w,h,0);
-                        //else
-                        //    liqcliprect_drawimageblendcolor(cr,easypaint_backgrain_image,x,y,w,h,bca,0);
-                        liqcliprect_drawboxwashcolor(     cr,x,y,w,h, bcu,bcv);
-                    }
-                }
-                
-                else
-                
-                {
-                    //bca=255;
-                    //if(bca==255)      // such a minute difference wont hurt too much
-                    if(bca>=254)
-                        liqcliprect_drawboxfillcolor(     cr,x,y,w,h,bcy,bcu,bcv);
-                    else
-                        liqcliprect_drawboxfillblendcolor(cr,x,y,w,h,bcy,bcu,bcv,bca);
-                }
+				// play...
+				if( (!self->image) && (self->classname) && (bca==255) && (bcc==0) )
+				{
+				    if(!easypaint_backgrain_image)
+				    {
+								// try allowing with alpha..
+				         easypaint_backgrain_image=liqimage_newfromfile("/usr/share/liqbase/libliqbase/media/backgrain.png",0,0,0);
+				    }
+				    if(easypaint_backgrain_image)
+				    {
+				        //if(bca==255)
+				            liqcliprect_drawimagecolor(cr,easypaint_backgrain_image,x,y,w,h,0);
+				        //else
+				        //    liqcliprect_drawimageblendcolor(cr,easypaint_backgrain_image,x,y,w,h,bca,0);
+				        liqcliprect_drawboxwashcolor(     cr,x,y,w,h, bcu,bcv);
+				    }
+				}
+				
+				else
+				
+				{
+				    //bca=255;
+				    //if(bca==255)      // such a minute difference wont hurt too much
+				    if(bca>=254)
+				        liqcliprect_drawboxfillcolor(     cr,x,y,w,h,bcy,bcu,bcv);
+				    else
+				        liqcliprect_drawboxfillblendcolor(cr,x,y,w,h,bcy,bcu,bcv,bca);
+				}
 			}
+			else
+			{
+				if(strncmp(t,"cube(",5) == 0 )
+				{
+					const char *tin=t+5;
+					int val=0;
+					while(*tin>='0' && *tin<='9')tin++;
+					if((tin) > (t+5))
+						val=atoi(t+5);
+					else
+						val=128;
+					if(val<0)val=0;
+					if(val>255)val=255;
+					// draw a colour cube :)
+				        liqcliprect_drawcolorcube(     cr,x,y,w,h,val);
+				}
+				else
+				if(strncmp(t,"greyrow",7) == 0 )
+				{
+					// draw a grey col :)
+				        liqcliprect_drawgreyrow(     cr,x,y,w,h);
+				}
+				else
+				if(strncmp(t,"greycol",7) == 0 )
+				{
+					// draw a grey col :)
+				        liqcliprect_drawgreycol(     cr,x,y,w,h);
+				}			}
+				
 		}
 	}
 __tz_one("backdone");
@@ -1011,10 +1031,17 @@ __tz_one("imageprep");
 
 		
 		char *fstr=liqcell_propgets(self,"imagefloat",NULL);
+		// LOL! drunken mode
+		// really, doing this makes the UI totally amazingly swimmingly dizzyfying it's unreal
+		// do not enable this unless at student partys or workmates desks
+		if(liqcell_liqfloat_drunkenmode)
+			if( (!fstr) || (*fstr==0) ){ fstr="0"; }
+		
 		if(fstr && *fstr)
 
+
 		{
-		//	liqapp_log("imagefloat: start '%s' %i,%i",self->name,w,h);
+			//liqapp_log("imagefloat: start '%s' %i,%i, '%s'",self->name,w,h,fstr);
 			
 			{
 
@@ -1029,13 +1056,13 @@ __tz_one("imageprep");
 				
 				
 				
-				liqcell_propsets_printf(self,"imagefloat","%f,%f,%f,%f",secs+0.1,0,0,0);
+				liqcell_propsets_printf(self,"imagefloat","%f",secs+0.1);
 				
 				
 				
 
 				
-				unsigned int rndofname = *(unsigned int *)self->name;
+				unsigned int rndofname = *(unsigned short *)self->name;
 				
 				secs+=rndofname;
 
@@ -1066,7 +1093,7 @@ __tz_one("imageprep");
 		
 		
 
-				//liqapp_log("imagefloat: '%s' orig  %4i,%4i - %4i,%4i     into     %4i,%4i - %4i,%4i",self->name,x,y,w,h,  xx,yy,rw,rh );
+				//liqapp_log("imagefloat: '%s' orig  %4i,%4i - %4i,%4i     into     %4i,%4i - %4i,%4i s=%f",self->name,x,y,w,h,  xx,yy,rw,rh , secs );
 
 
 				if(liqcell_propgeti(self,"lockaspect",1)==1)
@@ -1108,7 +1135,25 @@ __tz_one("imagedone");
 	liqcell *content = liqcell_getcontent(self);
 	if(content)
 	{
-		//liqapp_log("content1 = %s",content->name);
+
+
+			// THIS WILL SLOW DOWN RENDERING
+			// find out if orientation flipped.
+			if((triedlayout==0) && (liqcell_handlerfind(content,"layout")))
+			{
+				if( canvas.pixelwidth != liqcell_getw(content) )
+				{
+					//liqapp_log("liqcell_easypaint LAYOUT 1 can.w(%d) != self.w(%d) %s",canvas.pixelwidth,liqcell_getw(self),self->name);
+					// something changed, a glitch in the matrix.
+					liqcell_handlerrun(content,"layout",NULL);	
+					//liqapp_log("liqcell_easypaint LAYOUT 2 can.w(%d) ?= self.w(%d) %s",canvas.pixelwidth,liqcell_getw(self),self->name);
+					//triedlayout = 1;
+					//goto layoutrestart;
+
+
+				}
+			}
+		//liqapp_log("content1 = %s  xy(%d,%d) wh(%d,%d)",content->name,x,y,w,h);
 		// 20090414_012212 lcuk : allow for content which is not visible to be added but make sure we dont render it
 		if(liqcell_getvisible(content))
 		{
@@ -1604,12 +1649,40 @@ __tz_one("fontdone");
 			int sh = self->h;
 
 			// 20090412_174750 lcuk : adjusted again because overflows were still occuring, this only effects the factors and shouldnt have a visual effect at all
-			while(ww>16000){  ww>>=1; sw>>=1; }
-			while(hh>16000){  hh>>=1; sh>>=1; }
+		//	while(ww>16000){  ww>>=1; sw>>=1; }
+		//	while(hh>16000){  hh>>=1; sh>>=1; }
+		//	liqcell_easypaint(c,cr,x+c->x* ww/sw,y+c->y* hh/sh,c->w * ww /sw ,c->h * hh / sh);
 
+
+
+
+
+			// 20110530 lcuk trying again for 2008 missing
+/*
+			{
+				while( ((ww>1) && (sw>1) && (hh>1) && (sh>1)) && ((ww>8191) || (hh>8191) || (sw>8191) || (sh>8191)) )
+				{  
+					liqapp_log("spiralA wh(%d,%d)  swh(%d,%d) '%s'",ww,hh,  sw,sh,self->name);
+					ww>>=1; sw>>=1;  hh>>=1; sh>>=1; 
+					liqapp_log("spiralB wh(%d,%d)  swh(%d,%d) '%s'",ww,hh,  sw,sh,self->name);
+				}
+				typedef long long UL;
+				UL ax = ((UL)x) + ((UL)((UL)c->x) * ((UL)ww)) / ((UL)sw);
+				UL ay = ((UL)y) + ((UL)((UL)c->y) * ((UL)hh)) / ((UL)sh);
+				UL aw =           ((UL)((UL)c->w) * ((UL)ww)) / ((UL)sw);
+				UL ah =           ((UL)((UL)c->h) * ((UL)hh)) / ((UL)sh);
+				liqapp_log("spiralC a( xy(%d,%d) wh(%d,%d)) '%s'",ax,ay,aw,ah,self->name);
+				liqcell_easypaint(c,cr,ax,ay,aw,ah);
+			}
+*/
+
+
+			// 20110530 lcuk simplify again
+			while(ww>8191){  ww>>=1; sw>>=1; }
+			while(hh>8191){  hh>>=1; sh>>=1; }
 			liqcell_easypaint(c,cr,x+c->x* ww/sw,y+c->y* hh/sh,c->w * ww /sw ,c->h * hh / sh);
+			
 
-			//liqcell_easypaint(c,cr,x+c->x* w/self->w,y+c->y* h/self->h,c->w * w /self->w ,c->h * h / self->h);
 
 		}
 		//c=liqcell_getlinkprev(c);
@@ -1653,18 +1726,55 @@ __tz_one("borderdone");
 				if(p->w < self->w)
 				{
 					// show a position indicator bar..
+					// show a position indicator bar..
 					
+					float sx = self->x;
+		//			float sy = self->y;
+					float ww = w;
+					float sw = self->w;
+					float pw = p->w;
+		//			float hh = h;
+		//			float sh = self->h;
+		//			float ph = p->h;		
+					// ph = 480
+					// sh = 2000
+					// sy = -200
+					// get the relative size of the knob as a fraction of total height             == (0.25)
+					float f  = pw    / sw;
+					// get the relative offset of the knob as a fraction of total height           == (0.10)
+					float fx = (-sx) / sw;
+					// transform the knob size (0.25) into the context of the parent height (480/2000)  == (0.06)
+					float f2 = f * (pw / sw);						
+					// transform the knob offset (0.1) into the context of the parent height 0.1 + (480/2000) == (0.124) and starting from the parent offset
+					float fx2 = fx + (fx * (pw / sw));					
+
+
+					// adjust now the w element so that knob is onscreen correctly
+
+
+
+
+					// find the position for the knobble in relation to the window
+					float sy = self->y;			//-200
+					float sh = self->h;			// 2000
+					float ph = p->h	;			// 1000
+					float bb = ph + (-sy);
+					float hh = h;				// 800
+					float dd = ((float)bb) * ( ((float)h) / sh );
+
+					liqcliprect_drawboxwashcolor(cr,x+(fx2*ww),  y+dd-4, (f2*ww),4,0,255);				
 					
 				}
+				
+				
+				
+				
+				
 				if(p->h < self->h)
 				{
 					// show a position indicator bar..
 					
-					//float sx = self->x;
 					float sy = self->y;
-					//float ww = w;
-					//float sw = self->w;
-					//float pw = p->w;
 					float hh = h;
 					float sh = self->h;
 					float ph = p->h;		
@@ -1678,14 +1788,26 @@ __tz_one("borderdone");
 					// transform the knob size (0.25) into the context of the parent height (480/2000)  == (0.06)
 					float f2 = f * (ph / sh);						
 					// transform the knob offset (0.1) into the context of the parent height 0.1 + (480/2000) == (0.124) and starting from the parent offset
-					float fy2 = fy + (fy * (ph / sh));					
-					liqcliprect_drawboxwashcolor(cr,x+w-4,y+(fy2*hh) ,12,(f2*hh),0,255);
+					float fy2 = fy + (fy * (ph / sh));	
+					
+					// adjust now the w element so that knob is onscreen correctly
+
+					
+					// find the position for the knobble in relation to the window
+					float sx = self->x;			//-200
+					float sw = self->w;			// 2000
+					float pw = p->w	;			// 1000
+					float bb = pw + (-sx);
+					float ww = w;				// 800
+					float dd = ((float)bb) * ( ((float)w) / sw );
+
+					liqcliprect_drawboxwashcolor(cr,x+dd-4,y+(fy2*hh) ,4,(f2*hh),0,255);
 					
 				}
 			}
 	}
 
- 
+
 __tz_one("scrolldone");
 
 
@@ -1748,10 +1870,17 @@ __tz_one("selecteddone");
 		if(liqcell_handlerfind(self,"click") || liqcell_handlerfind(self,"mouse"))
 		{
 
+			t = liqcell_propgets(self,"backcolor",NULL);
+			if(t && !(decodecolor(t, &bcy, &bcu, &bcv , &bca,&bcc)))
+			{
+				// cube() greycol greyrow etc
+			}
+			else
+
 
 			//liqapp_log("textcolor :: '%s'",t);
 			//if(decodecolor(t, &bcy, &bcu, &bcv , &bca))
-        	if(h<240)  // shock!   was w<400 && h<240
+	        	if(h<240)  // shock!   was w<400 && h<240
 			{
 	
 				t = "rgb(160,206,232)";
@@ -1820,9 +1949,11 @@ __tz_one("presseddone");
 
 					int ww=liqfont_textwidth (infofont,info);
 					int hh=liqfont_textheight(infofont);
-					int ys=y+(h-hh)/2;
+					//int ys=y+(h-hh)/2;
 
-					liqcliprect_drawtextinside_color( cr, infofont,  x,ys,    ww,hh, info,0, 255,128,128);
+					int ys=y+(h-hh);
+					//liqcliprect_drawrect_color( cr, x,ys,    ww,hh, 255,128,128);
+					liqcliprect_drawtextinside_color( cr, infofont,  x+w-ww,ys,    ww,hh, info,0, 255,128,128);
 					
 					
 					if(liqcell_getclassname(self))
