@@ -23,8 +23,7 @@
  */
 
 // if liqbase is run in wallmount mode, make sure this is set
-//#define LIQBASE_WALLMOUNT
-
+#define LIQBASE_WALLMOUNT 1
 
 // 20090728_001621 lcuk : set this to have a 25fps limit to framerate, otherwise runs at fastest possible
 //#define LIMIT_FRAMERATE 1
@@ -89,6 +88,8 @@ liqcell * liqcell_easyrun_currentdialog=NULL;
 liqcell * liqcell_easyrun_activecontrol=NULL;
 int liqcell_easyrun_fingerpressed=0;
 
+int liqcell_easyrun_autorotating=0;				// new flag to indicate we should be autorotating
+
 
 //########################################################################
 //########################################################################
@@ -111,9 +112,200 @@ static struct liqcell_easyrunstack
 	int hity;
 	int hitw;
 	int hith;
+	liqcell *OpenSwipeList;
 }
 	       liqcell_easyrunstack[liqcell_easyrunstack_total];
 static int liqcell_easyrunstack_used=-1;
+
+
+
+		static int worldmouse(liqcell *self, liqcellmouseeventargs *args, liqcell *world)
+		{
+			liqapp_log("RunOpenSwipe mouse 1 mex(%d)", args->mex);
+			int direction = liqcell_propgeti(self,"direction",0);
+			liqcell_propseti(self,"position",args->mex);
+			liqcell_handlerrun(self,"layout2",NULL);
+			if(args->mcnt==0)
+			{
+				// starting
+				liqapp_log("RunOpenSwipe mouse 2");
+			}
+			else
+			{
+				if(args->mez>0)
+				{
+					// in progress
+					liqapp_log("RunOpenSwipe mouse 3");
+				}
+				else
+				{
+					// finishing
+					liqapp_log("RunOpenSwipe mouse 4");
+
+					//liqcell_setvisible(world,0);
+					liqcell_propseti(self,"inmotion",0);
+					
+				}
+			}
+			liqapp_log("RunOpenSwipe mouse 5");
+			return 0;
+		}
+		static int worldpaint(liqcell *self, liqcelleventargs *args, liqcell *world)
+		{
+			int inmotion = liqcell_propgeti(self,"inmotion",0);
+			if(inmotion==0)
+			{
+				int direction = liqcell_propgeti(self,"direction",0);
+				int position = liqcell_propgeti(self,"position",0);
+				int width = liqcell_getw(self);
+
+				if(position > (width/2))
+				{
+					if((width-position) < (8)) liqcell_setvisible(world,0);
+					position =position + ( (width-position) / 3 );
+
+
+				}
+				else
+				{
+					if((position) < (8)) liqcell_setvisible(world,0);
+					position = position - (position / 3);
+
+				}
+				liqcell_propseti(self,"position",position);
+				liqcell_handlerrun(self,"layout2",NULL);
+				liqcell_setdirty(self,1);
+			}
+			return 0;
+		
+		}
+		static int worldlayout(liqcell *self, liqcelleventargs *args, liqcell *world)
+		{
+			liqapp_log("RunOpenSwipe layout 1");
+			int direction = liqcell_propgeti(self,"direction",0);
+			int position = liqcell_propgeti(self,"position",0);
+			int width = liqcell_getw(self);
+			int hh = liqcell_geth(self);
+			liqapp_log("RunOpenSwipe layout 2 dir(%d) pos(%d) wid(%d)",direction,position,width);
+			
+			float fracfrom = (float)position / (float)width;
+			float fracto = (float)(width-position) / (float)width;
+			liqcell *left = liqcell_child_lookup(self,"left");
+			liqcell *middle = liqcell_child_lookup(self,"middle");
+			liqcell *right = liqcell_child_lookup(self,"right");
+
+			liqapp_log("RunOpenSwipe layout 3  from(%3.3f) to(%3.3f)",fracfrom,fracto);
+			if(direction<0)
+			{
+				liqcell_setrect(left, 0,0, width * fracfrom,hh);
+				liqcell_setrect(middle, width * fracfrom,0, width,hh);
+				liqcell_setrect(right, 0,0, 00,00);
+			}
+			else
+			{
+				liqcell_setrect(left, 0,0, 00,00);
+				liqcell_setrect(middle, (width * fracfrom) - width,0, width,hh);
+				liqcell_setrect(right, width * fracfrom,0, width * fracto,hh);
+			}
+			liqapp_log("RunOpenSwipe layout 4");
+			
+			return 0;
+		}
+
+liqcell *RunOpenSwipeMode(liqcell *self, int direction, int position, liqcell *OpenSwipeList)
+{
+	// this will return a new "self"
+	// 
+	liqapp_log("RunOpenSwipeMode 1");
+
+	liqcell *prev = NULL;
+	liqcell *next = NULL;
+
+	liqcell *lastcc=NULL;
+	liqcell *firstcc=NULL;
+
+		liqcell *c = liqcell_getlinkchild_visible(OpenSwipeList);
+		while(c)
+		{
+			liqcell *cc = liqcell_getcontent(c);
+			if(!firstcc)firstcc=cc;
+
+			if(cc == self)
+			{
+				prev=lastcc;
+				liqcell *d=liqcell_getlinknext_visible(c);
+				if(d)
+				{
+					liqcell *dd=liqcell_getcontent(d);
+					if(dd)
+					{
+						next=dd;
+					}
+				}
+				//break;
+			}
+			lastcc=cc;
+			c=liqcell_getlinknext_visible(c);
+		}
+		if(!next)next=firstcc;
+		if(!prev)prev=lastcc;
+		
+	liqapp_log("RunOpenSwipeMode 2");	
+
+	
+
+		liqcell *b;
+		
+		int ww = self->w;
+		int hh = self->h;
+		liqcell *world = liqcell_quickcreatevis("world","stage",  0,0,ww,hh);
+			liqcell *left = liqcell_quickcreatevis("left","hand",  0,0,ww/3,hh);
+			//liqcell_propsets(  left, "backcolor", "rgb(60,0,0)" );
+			liqcell_propseti(left,"lockaspect",1);
+			liqcell_setcontent(left,  prev  );
+			liqcell_child_append( world, left );
+
+			liqcell *middle = liqcell_quickcreatevis("middle","focus",  ww/3,0,ww/3,hh);
+			//liqcell_propsets(  middle, "backcolor", "rgb(0,60,0)" );
+			liqcell_setcontent(middle, self   );
+			liqcell_child_append( world, middle );
+			liqcell *right = liqcell_quickcreatevis("right","hand",  (ww/3)*2,0,ww/3,hh);
+			//liqcell_propsets(  right, "backcolor", "rgb(0,0,60)" );
+			liqcell_propseti(right,"lockaspect",1);
+			liqcell_setcontent(right,  next   );
+			liqcell_child_append( world, right );
+			liqcell_handleradd_withcontext(world,    "mouse",   (void *)worldmouse, world);
+			liqcell_handleradd_withcontext(world,    "layout2",   (void *)worldlayout, world);
+			liqcell_handleradd_withcontext(world,    "paint",   (void *)worldpaint, world);
+			liqcell_propseti(world, "direction", direction);
+			liqcell_propseti(world,"position",position);
+			liqcell_propseti(world,"inmotion",1);
+			liqcell_propseti(world,"dialog_zoomed",1);
+			liqcell_handlerrun(world,"layout2",NULL);
+	liqapp_log("RunOpenSwipeMode 3");
+		liqcell_easyrun(world);
+
+	liqcell *retval = self;
+		int newposition = liqcell_propgeti(world,"position",position);
+		if(direction<0)
+		{
+			if(newposition > self->w/2)
+			{
+				retval = prev;
+			}
+		}
+		else
+		{
+			if(newposition < self->w/2)
+			{
+				retval = next;
+			}
+		}
+	liqapp_log("RunOpenSwipeMode 4");
+
+	//liqcell_release(world);
+	return retval;
+}
 	
 //########################################################################
 //########################################################################
@@ -193,7 +385,9 @@ static void liqcellmouseeventargs_stroke_start(liqcellmouseeventargs *self,int m
 	self->multiy=0;
 	self->multiw=0;
 	self->multih=0;
-
+	
+	self->ox=0;
+	self->oy=0;
 
 	liqstroke_clear(self->stroke);
 	liqstroke_start(self->stroke,mx,my,mz,mt);
@@ -219,6 +413,9 @@ static void liqcellmouseeventargs_stroke_extend(liqcellmouseeventargs *self,int
 	self->mez=mz;
 	self->met=mt;
 
+	self->ox=0;
+	self->oy=0;
+
 	liqstroke_extend(self->stroke,mx,my,mz,mt);
 
 }
@@ -369,10 +566,7 @@ static void savethumb(liqcell *cell)
 
 				liqimage_pagesavepng(img,buf);
                 
-                
-                void post_to_liqbase_net(const char *filename, const char *datakey);
-                
-                post_to_liqbase_net(buf,"screenshot");
+
 
 
 //01:49:32 png writing png
@@ -793,7 +987,9 @@ int liqcell_easyrun(liqcell *self)
     liqcanvas_settitle( liqcell_getcaption(self) );
 	
 	
-	
+    if(liqcell_propgeti(self,"autorotate",0)==1)
+		liqcell_easyrun_autorotating++;
+    
 	
 	// what i should do is resize the contents to match the frame
 	// - actually, that may happen more than once per session
@@ -836,10 +1032,26 @@ int idle_lazyrun_wanted = liqcell_propgeti(self,"idle_lazyrun_wanted",0);
 	liqcell_easyrunstack[liqcell_easyrunstack_used].keyargs = NULL;
 	liqcell_easyrunstack[liqcell_easyrunstack_used].clickargs = NULL;
 	
+	liqcell_easyrunstack[liqcell_easyrunstack_used].OpenSwipeList = NULL;
 	
 
 
 
+
+	if(strcmp(self->name,"liqbase-playground")==0)
+	{
+		liqapp_log("RunOpenSwipeMode config 1");
+		    liqcell *body = liqcell_child_lookup(self,"body");
+		    if(body)
+		    {
+			liqapp_log("RunOpenSwipeMode config 2");
+		    	liqcell_easyrunstack[liqcell_easyrunstack_used].OpenSwipeList = body;
+		    }
+
+		   liqapp_log("RunOpenSwipeMode config 3");
+    
+	}
+
 	
 
 
@@ -910,6 +1122,12 @@ int fadeaty = 0;
 float fadeupto = 0.0;
 
 
+
+int slidemode = 0;		// slide is set to 0 == not moving, -1 == moving to previous, 1 == moving to next
+int slideuptox = 0;
+int slidestartx = 0;
+
+
 	
 	if( (liqcell_propgeti(self,"dialog_zoomed",0))  || (liqcell_easyrunstack_used==0))
 	{
@@ -1129,6 +1347,7 @@ waitevent:
 			if( (ev.type == LIQEVENT_TYPE_KEY) && (ev.state==LIQEVENT_STATE_PRESS) && (ev.key.keycode==65307) )	//ESC
 			{
 				liqapp_log("Escape Pressed, Cancelling");
+				savethumb( self );
 				//running=0;
 				if(fadestartx || fadestarty)
 				{	fademode=-1;  fadeatx=0; fadeaty=0; }
@@ -1248,14 +1467,14 @@ waitevent:
 			else if(ev.type == LIQEVENT_TYPE_MOUSE && (zoom_in_progress==0)  && (fademode==0)  )// && ev.mouse.pressure==0)
 			{
 				// mouse moving! w00t
-				
+
 				// lets just make sure we let this variable know
 				liqcell_easyrun_fingerpressed = (ev.mouse.pressure>0);
 
 				// get hold of actual coordinates...
 				int mx=ev.mouse.x;
 				int my=ev.mouse.y;
-				liqapp_log("event mouse scrn (%i,%i)",mx,my);
+			//	liqapp_log("event mouse scrn (%i,%i)",mx,my);
 			
 				mx -= fadeatx;	// let this have its position adjusted
 				my -= fadeaty;
@@ -1266,17 +1485,59 @@ waitevent:
 				wy=0;
 
 				vgraph_convert_target2window(graph ,mx,my,  &wx,&wy);
-				liqapp_log("mouse scrn (%i,%i)   cell (%i,%i)",mx,my,  wx,wy);
+			//	liqapp_log("mouse scrn (%i,%i)   cell (%i,%i)",mx,my,  wx,wy);
 				
 
 				hotx=0;
 				hoty=0;
 
 
-
-
 			if(mouseargs.mcnt==0)
 			{
+				// OpenSwipe, if we have a swipe list, if the cursor is starting on the swipe zone we run the swipe transition instead.
+				if( liqcell_easyrunstack[liqcell_easyrunstack_used-1].OpenSwipeList )
+				{
+
+					int gx = self->w/15;
+					int gy = self->h/10;
+						liqapp_log("OpenSwipe Start1 %3d,%3d,%3d",my,gy,canvas.pixelheight-gy);
+					if(my>gy && my<canvas.pixelheight-gy)
+					{
+						liqapp_log("OpenSwipe Start2 %3d,%3d,%3d",mx,gx,canvas.pixelwidth-gx);
+						if(mx < gx)
+						{
+							// enter swipe mode for giggles
+							liqcell *retval = RunOpenSwipeMode(self, -1 ,mx, liqcell_easyrunstack[liqcell_easyrunstack_used-1].OpenSwipeList );
+							mouseargs.mcnt=0;
+							liqcell_easyrun_fingerpressed=0;
+							if(retval && (retval!=self))
+							{
+								//liqcell *retval = 
+								liqcell_easyrunstack[liqcell_easyrunstack_used].runself = retval;
+								self = retval;
+								targetcr = easyrun_realtime_reshape(self, graph);
+							}
+							goto quickfin;
+						}
+						if( mx > (canvas.pixelwidth-gx))
+						{
+							// enter swipe mode for giggles
+							liqcell *retval = RunOpenSwipeMode(self, 1 ,mx, liqcell_easyrunstack[liqcell_easyrunstack_used-1].OpenSwipeList );
+							mouseargs.mcnt=0;
+							liqcell_easyrun_fingerpressed=0;
+							if(retval && (retval!=self))
+							{
+								//liqcell *retval = 
+								liqcell_easyrunstack[liqcell_easyrunstack_used].runself = retval;
+								self = retval;
+								targetcr = easyrun_realtime_reshape(self, graph);
+							}
+							goto quickfin;
+						}
+					}
+				}
+				
+			
 				hot = liqcell_easyhittest(self, wx,wy, &hotx,&hoty);
 				//hot = hit;//liqcell_easyhittest(self, wx,wy, &hotx,&hoty);
 				//liqcell *sel = hot;
@@ -1312,6 +1573,8 @@ waitevent:
 						mouseargs.hit = hot;
 						
 						liqcell_easyrun_activecontrol = hot;
+						
+						//liqapp_log("clck:stt %s",hot->name);
 
 
 
@@ -1333,6 +1596,11 @@ waitevent:
 						// in progress
 						liqcellmouseeventargs_stroke_extend(&mouseargs,wx,wy,ev.mouse.pressure);
 
+
+						
+						//liqapp_log("clck:mid %s",hot->name);
+
+
 						omex=mx;
 						omey=my;
 
@@ -1343,6 +1611,10 @@ waitevent:
 						// completed
 						liqcellmouseeventargs_stroke_extend(&mouseargs,wx,wy,ev.mouse.pressure);
 
+
+						
+						//liqapp_log("clck:fin %s",hot->name);
+						
 						omex=mx;
 						omey=my;
 
@@ -1389,7 +1661,11 @@ waitevent:
 
 
 
-							if( ((omsx)<80) && (omsy<56) && ((omex)<80) && (omey<56) )
+
+
+
+
+							if(  ( ((omsx)<80) && (omsy<56) && ((omex)<80) && (omey<56) ) && ( liqcell_easyrun_hide_back==0) )
 							{
 								if(ev.mouse.pressure!=0)
 								{
@@ -1466,7 +1742,9 @@ waitevent:
 // even for more than simple widgets
 
 
-
+							mouseargs.ox=0;
+							mouseargs.oy=0;
+	
 
 				if(hot)// && hot==mouseargs.hit)
 				{
@@ -1498,6 +1776,7 @@ waitevent:
 							liqcell *ohit=vhit;
 							while(ohit && ohit!=self)
 							{
+								//liqapp_log("huh easyrun (%d,%d) += (%d,%d) '%s'",ox,oy,ohit->x,ohit->y,ohit->name);
 								ox+=ohit->x;
 								oy+=ohit->y;
 								ohit=liqcell_getlinkparent(ohit);
@@ -1508,7 +1787,7 @@ waitevent:
 							
 							
 							liqcell_easyrun_mouseeventargs_multitouchprepare(vhit,&mouseargs,NULL);
-
+							
 							if( liqcell_handlerrun(vhit,"mouse",&mouseargs) )
 							{
 								// handled it \o/
@@ -1519,6 +1798,10 @@ waitevent:
 								}
 							}
 						}
+						else
+						{
+							// NO mouse event handler - we should now try to slide..
+						}
 					}
 
 
@@ -1583,6 +1866,60 @@ waitevent:
 								}
 							}
 						}
+
+
+
+
+
+						else
+						{
+							// NO click event handler
+							// this is essentially a free hit
+							// if i
+							int dx = mouseargs.stroke->pointlast->x - mouseargs.stroke->pointfirst->x;
+							int dy = mouseargs.stroke->pointlast->y - mouseargs.stroke->pointfirst->y;
+							int ar=0;
+							liqapp_log("ARGMOUSE xy(%d,%d)",dx,dy);
+							if(ABS(dx)>ABS(dy) ) // && ((ABS(dx)/4) > ABS(dy)))
+							{
+								
+								liqapp_log("ARGMOUSE2 xy(%d,%d)",dx,dy);
+								
+								liqcell *adj;
+								if(dx<0)
+								{
+									adj = liqcell_getlinkprev_visual(self);
+								}
+								else
+								{
+									adj = liqcell_getlinknext_visual(self);
+								}
+								if(adj)
+								{
+									liqapp_log("ARGMOUSE 2 xy(%d,%d) '%s'",dx,dy,adj->name);
+									// swap self
+									liqcell *orig=self;
+									if(liqcell_getselected(orig))
+									{
+										liqcell_setselected(self,0);
+										liqcell_setselected(adj,1);
+										
+									}
+									liqcell_ensurevisible_centred(adj);
+									self=adj;
+									dirty=1;
+									//targetcr = easyrun_realtime_reshape(self, graph);
+									
+								}
+							}
+							
+						}
+
+
+
+
+
+
 					}
 
 				}
@@ -1855,7 +2192,7 @@ moar:
 		 // because by putting it here messes up normal stuff and thats not desired
 		 // put it back again (31/12)
 		 // changed it yet again to be a specific, per dialog flag
-		if( (dirty==0) && (refreshinprogress==0) && (mouseargs.mcnt==0) && (liqcell_propgeti(self,"autorotate",0)==1) )// liqapp_pref_checkexists("autorotate") )
+		if( (dirty==0) && (refreshinprogress==0) && (mouseargs.mcnt==0) && (liqcell_easyrun_autorotating) )// liqapp_pref_checkexists("autorotate") )
 		{
 			int aax=0;
 			int aay=0;
@@ -1865,8 +2202,34 @@ moar:
 			dirty=1;
 			
 		}
+
+
 		
 		
+
+			// find out if orientation flipped.
+			if(liqcell_handlerfind(self,"layout"))
+			{
+				if( canvas.pixelwidth != liqcell_getw(self) )
+				{
+					// something changed, a glitch in the matrix.
+					//liqapp_log("liqcell_easyrun   LAYOUT 1 can.w(%d) != self.w(%d) %s",canvas.pixelwidth,liqcell_getw(self),self->name);
+					liqcell_handlerrun(self,"layout",NULL);	
+					//liqapp_log("liqcell_easyrun   LAYOUT 2 can.w(%d) ?= self.w(%d) %s",canvas.pixelwidth,liqcell_getw(self),self->name);
+
+					// #############################################	
+
+					targetcr = easyrun_realtime_reshape(self, graph);
+				
+					refreshinprogress=0;
+					wantwait=0;
+					dirty=1;
+
+				}
+			}
+
+
+					
 		
 		if(((dirty==1) && (refreshinprogress==0)))
 		{
@@ -1960,7 +2323,7 @@ moar:
 
 			
 			vgraph_drawcell(graph,x,y,w,h,self);
-			
+		
 			//liqapp_log("render adding nav items");
 			static liqimage *infoback=NULL;
 			static liqimage *infoclose=NULL;
@@ -1988,13 +2351,16 @@ moar:
                 
 			}
 
+
+
+
 #ifdef LIQBASE_WALLMOUNT
 
 			if(infoback && infoclose &&     (liqcell_easyrun_hide_back==0)    )
 			{
 				//liqapp_log("************************************************************************************** use");
 				if(liqcell_easyrun_depth==1)
-					liqcliprect_drawimagecolor(targetcr, infoclose, 0,liqcliprect_getw(targetcr)-48,48,48, 1);
+					liqcliprect_drawimagecolor(targetcr, infoclose, 0,liqcliprect_geth(targetcr)-48,48,48, 1);
 				else
 				
 					liqcliprect_drawimagecolor(targetcr, infoback , 0,liqcliprect_geth(targetcr)-48,48,48, 1);
@@ -2148,7 +2514,8 @@ if(liqcell_showfps)
 	
 	liqcell_historystore_historythumb(self);			// lol!
 
-    
+    if(liqcell_propgeti(self,"autorotate",0)==1)
+		liqcell_easyrun_autorotating--;
     
 	
 	return result;
